@@ -75,6 +75,7 @@ struct TabletToolAxisEvent;
 struct TabletToolTipEvent;
 class Window;
 class WindowItem;
+class WindowPropertyNotifyX11Filter;
 class WorkspaceScene;
 class VirtualDesktop;
 class EglContext;
@@ -1110,6 +1111,7 @@ protected:
     WorkspaceScene *m_scene;
     QList<Effect *> m_grabbedMouseEffects;
     EffectLoader *m_effectLoader;
+    std::unique_ptr<WindowPropertyNotifyX11Filter> m_x11WindowPropertyNotify;
 };
 
 /**
